/*
ip_nat_cfg.c
*/

/* *************************************************************** */
/* NAT working mode static parameters adjustment */

/* . */
/* set static IPv4r2 NAT relations here */
static init_ip_nat_t init_ip_nat[]={
	/*
	IPv4r2 if must be the same as IPv4
	then must be placed first in the list 
	oroute IPv4r2->IPv4 can be used 
	to post any IPv4r2 into IPv4 dst
	*/
	/*{"169.254.0.111",{"192.168.101.111","0/0/1","2",""}},*/
	{"169.254.0.121",{"192.168.101.121","0/0/2","3",""}},
	{"169.254.0.131",{"192.168.101.131","0/0/3","4",""}},
	/* examples */
	{"169.254.0.1",{"192.168.101.1","","",""}},
	/* 
	can not NAT to own IPv4 (own_IPv4 == 192.168.101.11), 
	can map it there only (map 192.168.101.11 to 169.254.0.11)
	{"169.254.0.11",{"192.168.101.11","","",""}}, 
	*/
	{"169.254.0.12",{"192.168.101.12","","",""}},
	{"169.254.0.13",{"192.168.101.13","","",""}}
}; 

/* . */
/* map NAT local own IPv4 into local address space of IPv4r2 NAT table */
static char is_map_own_IPv4= 1;
	/* 
	do map own IPv4 specified
	just to map own IPv4 into IPv4r2 addr local area 
	without IPv4r2 translation 
	to work with all hosts in the same mapped local network
	by implementation 
		this is the same switch src/dst addr as for 127.0.0.1
		if dst == mapped_own_IPv4
	*/

/* IPv4r2 NAT table local address space is within ip_nat[].loc network */
static const char *init_mapped_own_IPv4= 
	/* example */
	"169.254.0.11";

/* . */
/* NAT own IPv4 */
static char is_own_IPv4= 1;
	/*
	NAT own IPv4 (local IPv4) specified
	to simplify relations between the NAT and local networks  
	we assume there is single local IPv4 only for NAT translation
	otherwise any local IPv4 will be used to do NAT
	*/

static const char *init_own_IPv4= 
	/* example */
	"192.168.101.11";

/* *************************************************************** */
/* . */
/* has own IPv4r2 */
static char is_own_IPv4r2= 0;
	/* 
	own IPv4r2 specified
	do substitute local IPv4 to IPv4r2 specified
	src on send: to send local IPv4 as IPv4r2 addr
	dst on receive: to translate the IPv4r2 addr to local IPv4
	(NAT works with opposite addr: dst on send and src on receive)
	otherwise local IPv4 will be unchanged 
	and asimmetric IPv4r2 access 'll be in use
	Note: only local IPv4 will be translated 
		(ip_port->ip_ipaddr == ip_hdr->ih_src)
		otherwise we can't restore IPv4r2 to IPv4 
	*/

static init_ip_nat_dst_t init_own_IPv4r2=
	/* example */
	{"192.168.101.111","0/0/1","2",""};

/* . */
/* has IPv4r2 src */
static char is_IPv4r2_src= 0;
	/*
	IPv4 for IPv4r2 specified
	do substitute IPv4r2_src to IPv4r2 specified
	it is usefull for minix working as LAN bridge 
	Note: only IPv4r2_src will be translated to IPv4r2 
		(IPv4r2_src == ip_hdr->ih_src)
		otherwise we can't restore IPv4r2 to IPv4 
	*/

static const char *init_IPv4r2_src= 
	/* example */
	"192.168.101.11";

/* *************************************************************** */
/* . */
/* force IPv4r2.x index format */
static char is_IPv4r2_gate_cmd= 1;
	/*
	IPv4r2.x index format specified (disable default IPv4r2 gate rules)
	set to 1 is req to IPv4r2.0 to disable IPv4r2 gate index usage
	*/

/* IPv4r2 gate command 4 low bits */
static const u8_t init_IPv4r2_gate_cmd= 
	/*
	set to 0 is req to IPv4r2.0 to disable IPv4r2 gate index usage
	*/
	0;

/* *************************************************************** */
/* . */
/* has IPv4r2 UDP incapsulation (UI) */
static char is_IPv4r2_UDP= 0;
	/*
	UDP incapsulation for IPv4r2 frame specified
	all IPv4r2 will be packed into IPv4 UDP frame
	and all incoming UDP frames will be checked for IPv4r2 to unpack
	*/

/* IPv4r2 UI magic signature */
static const u8_t IPv4r2_UDP_sign[4]= 
	/* by standard */
	{ 0x55, 0xaa, 0x42, 0x00 };

/* IPv4r2 UI service UDP port */
static const u16_t init_IPv4r2_UDP_port= 
	/* example */
	4;

/* has IPv4r2 network entry point */
static char is_IPv4r2_UDP_dst= 0;
	/*
	IPv4r2 network IPv4 entry point specified
	send all UDP incapsulated IPv4r2 frames into the dst
	there is path to IPv4r2 network and all UDP incapsulated IPv4r2 frames
	must be sent to the entry point
	otherwise UDP incapsulated IPv4r2 frames 
	will be sent to IPv4 root of IPv4r2 dst
	*/

static const char *init_IPv4r2_UDP_dst= 
	/* example */
	"192.88.99.1";

/* track IPv4r2 network broken path */
static char is_IPv4r2_UDP_own_src= 1;
	/*
	if set IPv4r2 UI frames will be sent from name of src of the host 
	which can not deliver pure IPv4r2 frame (src == ip_port->ip_ipaddr)
	otherwise IPv4r2 origin src will be used as UI src
	in the case UI replies will be posted back to origin as UI
	*/

/* allow IPv4r2 uni server addr */
static char is_IPv4r2_UDP_uni_dst= 0;
	/*
	if set IPv4r2_UDP read will accept 
	dst == IPv4r2_UDP_uni_dst to do UDP->IPv4r2 decapsulation
	otherwise only own IPv4 (dst == ip_port->ip_ipaddr) 
	will be used on read
	*/

/* unified IPv4 addr for servers between IPv4 and IPv4r2 */
static const char *init_IPv4r2_UDP_uni_dst= 
	/* example */
	"192.88.99.1";

/* unpack all UI incoming frames */
static char is_IPv4r2_UDP_read_all= 1;
	/*
	if set all incoming UDP farems with UI signature will be unpacked
	it is required for end-host if set is_own_IPv4r2 
	because IPv4 part of own_IPv4r2 can be no the same as ip_port->ip_ipaddr
	the propetry is controlled separatedly to unlink with "own_IPv4r2" subsystem 
	otherwise only allowed dst will be unpacked
	*/

/* *************************************************************** */
/* . */
/* NAT table size */
#define IP_NAT_ITEMS 64
	/* 
	while addr comparing is implemented as slow and not optimal to search
	that does not allow to use very many NAT items (about 64 max)
	because of performance penalty if the array is larger than the max
	*/

/**/
